# AI Governance
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#overview)
  * [What Is AI Governance?](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#what-is-ai-governance?)
  * [Why Is AI Governance Relevant?](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#why-is-ai-governance-relevant?)
  * [What Are the Benefits of AI Governance?](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#what-are-the-benefits-of-ai-governance?)
  * [Before You Start](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#before-you-start)
  * [Step-by-Step Guide](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#step-by-step-guide)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption#related-resources)


Learn how to implement AI governance practices in SAP LeanIX.
